@@ -36,9 +36,9 @@
 #include "ftpdirectoryparser.h"
 #include "ftpsocket.h"
 
-#include <ntqvaluevector.h>
-#include <ntqstringlist.h>
-#include <ntqdatetime.h>
+#include <tqvaluevector.h>
+#include <tqstringlist.h>
+#include <tqdatetime.h>
 
 #include <time.h>
 #include <sys/stat.h>
