@@ -171,7 +171,7 @@ Connection *Transfer::initializeSession(Session *session)
 {
   if (!session->isFreeConnection()) {
     // We should wait for a connection to come
-    connect(session, SIGNAL(freeConnectionAvailable()), this, SLOT(slotConnectionAvailable()));
+    connect(session, TQ_SIGNAL(freeConnectionAvailable()), this, TQ_SLOT(slotConnectionAvailable()));
     
     if (m_status != Waiting) {
       m_status = Waiting;
@@ -184,7 +184,7 @@ Connection *Transfer::initializeSession(Session *session)
   Connection *connection = session->assignConnection();
   connection->acquire(this);
   
-  connect(connection->getClient()->eventHandler(), SIGNAL(connected()), this, SLOT(slotConnectionConnected()));
+  connect(connection->getClient()->eventHandler(), TQ_SIGNAL(connected()), this, TQ_SLOT(slotConnectionConnected()));
   
   return connection;
 }
@@ -242,10 +242,10 @@ void Transfer::slotConnectionAvailable()
     return;
   
   if (m_srcSession)
-    m_srcSession->TQObject::disconnect(this, SLOT(slotConnectionAvailable()));
+    m_srcSession->TQObject::disconnect(this, TQ_SLOT(slotConnectionAvailable()));
   
   if (m_dstSession)
-    m_dstSession->TQObject::disconnect(this, SLOT(slotConnectionAvailable()));
+    m_dstSession->TQObject::disconnect(this, TQ_SLOT(slotConnectionAvailable()));
   
   // Connection has become available, grab it now
   execute();
@@ -291,10 +291,10 @@ void Transfer::resetTransfer()
   // Disconnect signals
   if (getStatus() != Waiting) {
     if (m_srcConnection)
-      m_srcConnection->getClient()->eventHandler()->TQObject::disconnect(this, SLOT(slotConnectionConnected()));
+      m_srcConnection->getClient()->eventHandler()->TQObject::disconnect(this, TQ_SLOT(slotConnectionConnected()));
     
     if (m_dstConnection)
-      m_dstConnection->getClient()->eventHandler()->TQObject::disconnect(this, SLOT(slotConnectionConnected()));
+      m_dstConnection->getClient()->eventHandler()->TQObject::disconnect(this, TQ_SLOT(slotConnectionConnected()));
   }
   
   // Reset connections & session pointers
