@@ -56,7 +56,7 @@ namespace CustomCommands {
  * @author Jernej Kos
  */
 class Entry : public TQObject {
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Possible parameter types.
