@@ -288,7 +288,7 @@ void generate_session_keys(SSH_SESSION *session);
 /* returns 1 if server signature ok, 0 otherwise. The NEXT crypto is checked, not the current one */
 int signature_verify(SSH_SESSION *session,STRING *signature);
 bignum make_string_bn(STRING *string);
-STRING *make_bignum_string(bignum num);
+STRING *make_bignum_string(const bignum num);
 
 /* in crypt.c */
 u32 packet_decrypt_len(SSH_SESSION *session,char *crypted);
