@@ -87,8 +87,8 @@ int QueueGroup::executeNextTransfer()
   // Get the transfer instance and schedule it's execution
   transfer->TQObject::disconnect(this);
   
-  connect(transfer, SIGNAL(transferComplete(long)), this, SLOT(incrementAndExecute()));
-  connect(transfer, SIGNAL(transferAbort(long)), this, SIGNAL(interrupted()));
+  connect(transfer, TQ_SIGNAL(transferComplete(long)), this, TQ_SLOT(incrementAndExecute()));
+  connect(transfer, TQ_SIGNAL(transferAbort(long)), this, TQ_SIGNAL(interrupted()));
 
   transfer->delayedExecute();
   
