@@ -34,14 +34,14 @@
  * files in the program, then also delete it here.
  */
 
-#include <ntqlayout.h>
-#include <ntqpushbutton.h>
-#include <ntqcheckbox.h>
-#include <ntqgroupbox.h>
-#include <ntqspinbox.h>
-#include <ntqsplitter.h>
-#include <ntqtextedit.h>
-#include <ntqtabwidget.h>
+#include <tqlayout.h>
+#include <tqpushbutton.h>
+#include <tqcheckbox.h>
+#include <tqgroupbox.h>
+#include <tqspinbox.h>
+#include <tqsplitter.h>
+#include <tqtextedit.h>
+#include <tqtabwidget.h>
 
 #include <tdeglobal.h>
 #include <kcharsets.h>
@@ -59,7 +59,7 @@
 
 #include "kftpapi.h"
 #include "kftpbookmarks.h"
-#include "misc/config.h"
+#include "misc/kftpconfig.h"
 #include "misc.h"
 
 #include "editor.h"
@@ -100,15 +100,15 @@ BookmarkEditor::BookmarkEditor(TQWidget *parent, const char *name)
 
   initDialog();
 
-  connect(this, SIGNAL(user1Clicked()), this, SLOT(slotImportWizard()));
-  connect(this, SIGNAL(user2Clicked()), this, SLOT(slotExportWizard()));
+  connect(this, TQ_SIGNAL(user1Clicked()), this, TQ_SLOT(slotImportWizard()));
+  connect(this, TQ_SIGNAL(user2Clicked()), this, TQ_SLOT(slotExportWizard()));
 
-  connect(m_tree, SIGNAL(bookmarkClicked(TQListViewItem*)), this, SLOT(slotTreeClicked(TQListViewItem*)));
-  connect(m_tree, SIGNAL(bookmarkNew(ListViewItem*, KFTPBookmarks::Site*)), this, SLOT(slotNewAction(ListViewItem*, KFTPBookmarks::Site*)));
-  connect(m_tree, SIGNAL(bookmarkDuplicated(ListViewItem*, KFTPBookmarks::Site*)), this, SLOT(slotDuplicateAction(ListViewItem*, KFTPBookmarks::Site*)));
-  connect(m_tree, SIGNAL(bookmarkDeleted()), this, SLOT(slotDeleteAction()));
-  connect(m_tree, SIGNAL(bookmarkMoved()), this, SLOT(refresh()));
-  connect(m_tree, SIGNAL(categoryRenamed()), this, SLOT(refresh()));
+  connect(m_tree, TQ_SIGNAL(bookmarkClicked(TQListViewItem*)), this, TQ_SLOT(slotTreeClicked(TQListViewItem*)));
+  connect(m_tree, TQ_SIGNAL(bookmarkNew(ListViewItem*, KFTPBookmarks::Site*)), this, TQ_SLOT(slotNewAction(ListViewItem*, KFTPBookmarks::Site*)));
+  connect(m_tree, TQ_SIGNAL(bookmarkDuplicated(ListViewItem*, KFTPBookmarks::Site*)), this, TQ_SLOT(slotDuplicateAction(ListViewItem*, KFTPBookmarks::Site*)));
+  connect(m_tree, TQ_SIGNAL(bookmarkDeleted()), this, TQ_SLOT(slotDeleteAction()));
+  connect(m_tree, TQ_SIGNAL(bookmarkMoved()), this, TQ_SLOT(refresh()));
+  connect(m_tree, TQ_SIGNAL(categoryRenamed()), this, TQ_SLOT(refresh()));
 
   // Get the new bookmark data
   m_tree->fillBookmarkData();
@@ -153,15 +153,15 @@ void BookmarkEditor::initDialog()
   m_properties->retryGroup->setEnabled(false);
   m_properties->defLocalDir->setMode(KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
 
-  connect(m_properties->anonLogin, SIGNAL(clicked()), this, SLOT(slotChangeAnonLogin()));
-  connect(m_properties->doRetry, SIGNAL(clicked()), this, SLOT(slotChangeActiveRetryGroup()));
-  connect(m_properties->doKeepalive, SIGNAL(clicked()), this, SLOT(slotChangeActiveKeepaliveGroup()));
-  connect(m_properties->protoAdvanced, SIGNAL(clicked()), this, SLOT(slotProtoAdvancedClicked()));
-  connect(m_properties->serverProtocol, SIGNAL(activated(int)), this, SLOT(slotChangeServerProtocol(int)));
-  connect(m_properties->serverPort, SIGNAL(valueChanged(int)), this, SLOT(slotPortChanged()));
+  connect(m_properties->anonLogin, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotChangeAnonLogin()));
+  connect(m_properties->doRetry, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotChangeActiveRetryGroup()));
+  connect(m_properties->doKeepalive, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotChangeActiveKeepaliveGroup()));
+  connect(m_properties->protoAdvanced, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotProtoAdvancedClicked()));
+  connect(m_properties->serverProtocol, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotChangeServerProtocol(int)));
+  connect(m_properties->serverPort, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotPortChanged()));
 
-  connect(this, SIGNAL(applyClicked()), this, SLOT(slotSaveActiveNode()));
-  connect(this, SIGNAL(okClicked()), this, SLOT(slotSaveActiveNode()));
+  connect(this, TQ_SIGNAL(applyClicked()), this, TQ_SLOT(slotSaveActiveNode()));
+  connect(this, TQ_SIGNAL(okClicked()), this, TQ_SLOT(slotSaveActiveNode()));
 
   // Populate charsets
   TQStringList charsets = TDEGlobal::charsets()->descriptiveEncodingNames();
