@@ -55,7 +55,7 @@ namespace Bookmarks {
 */
 class BookmarkEditorTLS : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
 public:
     BookmarkEditorTLS(TQWidget *parent = 0, const char *name = 0);
     ~BookmarkEditorTLS();
