@@ -103,17 +103,17 @@ ListView::ListView(KFTPBookmarks::Manager *bookmarks, TQWidget *parent, const ch
   // Init auto open timer
   m_openTimer = new TQTimer(this);
 
-  connect(this, SIGNAL(dropped(TQDropEvent*, TQListViewItem*)), this, SLOT(slotDropped(TQDropEvent*, TQListViewItem*)));
-  connect(this, SIGNAL(clicked(TQListViewItem*)), this, SLOT(slotClicked(TQListViewItem*)));
-  connect(this, SIGNAL(doubleClicked(TQListViewItem*)), this, SLOT(slotDoubleClicked(TQListViewItem*)));
-  connect(this, SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint&, int)), this, SLOT(slotContextMenu(TQListViewItem*, const TQPoint&, int)));
+  connect(this, TQ_SIGNAL(dropped(TQDropEvent*, TQListViewItem*)), this, TQ_SLOT(slotDropped(TQDropEvent*, TQListViewItem*)));
+  connect(this, TQ_SIGNAL(clicked(TQListViewItem*)), this, TQ_SLOT(slotClicked(TQListViewItem*)));
+  connect(this, TQ_SIGNAL(doubleClicked(TQListViewItem*)), this, TQ_SLOT(slotDoubleClicked(TQListViewItem*)));
+  connect(this, TQ_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint&, int)), this, TQ_SLOT(slotContextMenu(TQListViewItem*, const TQPoint&, int)));
 
   /* Init the actions */
-  m_newAction = new TDEAction(i18n("&New..."), "document-new", TDEShortcut(), this, SLOT(slotNewAction()), actionCollection(), "bookmark_new");
-  m_renameAction = new TDEAction(i18n("&Rename"), TDEShortcut(), this, SLOT(slotRenameAction()), actionCollection(), "bookmark_rename");
-  m_deleteAction = new TDEAction(i18n("&Delete"), "edit-delete", TDEShortcut(), this, SLOT(slotDeleteAction()), actionCollection(), "bookmark_delete");
-  m_subCatAction = new TDEAction(i18n("&Create Subcategory..."), "folder-new", TDEShortcut(), this, SLOT(slotSubCatAction()), actionCollection(), "bookmark_subcat");
-  m_copyAction = new TDEAction(i18n("&Duplicate"), TDEShortcut(), this, SLOT(slotDuplicateAction()), actionCollection(), "bookmark_duplicate");
+  m_newAction = new TDEAction(i18n("&New..."), "document-new", TDEShortcut(), this, TQ_SLOT(slotNewAction()), actionCollection(), "bookmark_new");
+  m_renameAction = new TDEAction(i18n("&Rename"), TDEShortcut(), this, TQ_SLOT(slotRenameAction()), actionCollection(), "bookmark_rename");
+  m_deleteAction = new TDEAction(i18n("&Delete"), "edit-delete", TDEShortcut(), this, TQ_SLOT(slotDeleteAction()), actionCollection(), "bookmark_delete");
+  m_subCatAction = new TDEAction(i18n("&Create Subcategory..."), "folder-new", TDEShortcut(), this, TQ_SLOT(slotSubCatAction()), actionCollection(), "bookmark_subcat");
+  m_copyAction = new TDEAction(i18n("&Duplicate"), TDEShortcut(), this, TQ_SLOT(slotDuplicateAction()), actionCollection(), "bookmark_duplicate");
 }
 
 TDEActionCollection *ListView::actionCollection()
@@ -126,7 +126,7 @@ void ListView::setAutoUpdate(bool value)
   m_autoUpdate = value;
 
   if (value)
-    connect(m_bookmarks, SIGNAL(update()), this, SLOT(slotAutoUpdate()));
+    connect(m_bookmarks, TQ_SIGNAL(update()), this, TQ_SLOT(slotAutoUpdate()));
 
   slotAutoUpdate();
 }
@@ -136,7 +136,7 @@ void ListView::setConnectBookmark(bool value)
   m_connectBookmark = value;
 
   if (value)
-    connect(this, SIGNAL(executed(TQListViewItem*)), this, SLOT(slotBookmarkExecuted(TQListViewItem*)));
+    connect(this, TQ_SIGNAL(executed(TQListViewItem*)), this, TQ_SLOT(slotBookmarkExecuted(TQListViewItem*)));
 }
 
 void ListView::setEditMenuItem(bool value)
