@@ -84,7 +84,7 @@ private:
 */
 class ListView : public KFTPWidgets::ListView
 {
-Q_OBJECT
+TQ_OBJECT
 public:
     ListView(KFTPBookmarks::Manager *bookmarks, TQWidget *parent = 0, const char *name = 0);
 
