@@ -77,9 +77,9 @@ Sidebar::Sidebar(TQWidget *parent, const char *name)
 
   layout->addWidget(m_tree);
 
-  m_editAction = new TDEAction(i18n("&Edit..."), "edit", TDEShortcut(), this, SLOT(slotEditAction()), actionCollection(), "bookmark_edit2");
-  connect(m_tree, SIGNAL(bookmarkClicked(TQListViewItem*)), this, SLOT(slotClicked(TQListViewItem*)));
-  connect(m_tree, SIGNAL(bookmarkNew(ListViewItem*, KFTPBookmarks::Site*)), this, SLOT(slotNewAction(ListViewItem*, KFTPBookmarks::Site*)));
+  m_editAction = new TDEAction(i18n("&Edit..."), "edit", TDEShortcut(), this, TQ_SLOT(slotEditAction()), actionCollection(), "bookmark_edit2");
+  connect(m_tree, TQ_SIGNAL(bookmarkClicked(TQListViewItem*)), this, TQ_SLOT(slotClicked(TQListViewItem*)));
+  connect(m_tree, TQ_SIGNAL(bookmarkNew(ListViewItem*, KFTPBookmarks::Site*)), this, TQ_SLOT(slotNewAction(ListViewItem*, KFTPBookmarks::Site*)));
 
   // Get the new bookmark data
   m_tree->fillBookmarkData();
