@@ -296,7 +296,7 @@ PermissionsPropsPlugin::PermissionsPropsPlugin(KPropertiesDialog *_props, KFileI
   for (int row = 0; row < 3; ++row) {
     for (int col = 0; col < 4; ++col) {
       TQCheckBox *cb = new TQCheckBox(gb);
-      connect(cb, SIGNAL(clicked()), this, SLOT(setDirty()));
+      connect(cb, TQ_SIGNAL(clicked()), this, TQ_SLOT(setDirty()));
       m_permsCheck[row][col] = cb;
       cb->setChecked(permissions & fperm[row][col]);
       
@@ -309,7 +309,7 @@ PermissionsPropsPlugin::PermissionsPropsPlugin(KPropertiesDialog *_props, KFileI
   
   if (isDir) {
     m_cbRecursive = new TQCheckBox(i18n("Apply changes to all subfolders and their contents"), frame);
-    connect(m_cbRecursive, SIGNAL(clicked()), this, SLOT(changed()));
+    connect(m_cbRecursive, TQ_SIGNAL(clicked()), this, TQ_SLOT(changed()));
     box->addWidget(m_cbRecursive);
   }
 }
