@@ -78,7 +78,7 @@ class FilterWidget;
  */
 class View : public TQWidget
 {
-Q_OBJECT
+TQ_OBJECT
 friend class Actions;
 friend class DetailsView;
 friend class ListView;
