@@ -76,7 +76,7 @@ private:
  */
 class FailedTransfers : public TQWidget
 {
-Q_OBJECT
+TQ_OBJECT
 public:
     FailedTransfers(TQWidget *parent = 0, const char *name = 0);
     ~FailedTransfers();
