@@ -60,7 +60,7 @@ class ListView;
  * @author Jernej Kos
  */
 class FilterConditionWidget : public TQWidget {
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Class constructor.
@@ -100,7 +100,7 @@ private:
  * @author Jernej Kos
  */
 class FilterConditionWidgetLister : public WidgetLister {
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Class constructor.
@@ -131,7 +131,7 @@ private:
  * @author Jernej Kos
  */
 class FilterConditionsList : public TQGroupBox {
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Class constructor.
@@ -167,7 +167,7 @@ private:
  * @author Jernej Kos
  */
 class FilterActionWidget : public TQWidget {
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Class constructor.
@@ -205,7 +205,7 @@ private:
  * @author Jernej Kos
  */
 class FilterActionWidgetLister : public WidgetLister {
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Class constructor.
@@ -236,7 +236,7 @@ private:
  * @author Jernej Kos
  */
 class FilterActionsList : public TQGroupBox {
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Class constructor.
@@ -267,7 +267,7 @@ private:
  * @author Jernej Kos
  */
 class FilterListView : public TQGroupBox {
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Class constructor.
@@ -345,7 +345,7 @@ private:
  * @author Jernej Kos
  */
 class FilterEditor : public TQWidget {
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Class constructor.
