@@ -55,7 +55,7 @@ namespace Bookmarks {
 */
 class KFTPSelectServerDialog : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
 public:
     KFTPSelectServerDialog(TQWidget *parent = 0, const char *name = 0);
 
