@@ -439,8 +439,8 @@ MultiTabBarButton::MultiTabBarButton(MultiTabBarInternal *tb, const TQPixmap& pi
   setFixedWidth(24);
   m_id = id;
   
-  connect(this, SIGNAL(clicked()), this, SLOT(slotClicked()));
-  connect(m_animTimer, SIGNAL(timeout()), this, SLOT(slotAnimTimer()));
+  connect(this, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotClicked()));
+  connect(m_animTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotAnimTimer()));
 }
 
 MultiTabBarButton::MultiTabBarButton(MultiTabBarInternal *tb, const TQString& text, TQPopupMenu *popup,
@@ -462,8 +462,8 @@ MultiTabBarButton::MultiTabBarButton(MultiTabBarInternal *tb, const TQString& te
   setFixedWidth(24);
   m_id = id;
   
-  connect(this, SIGNAL(clicked()), this, SLOT(slotClicked()));
-  connect(m_animTimer, SIGNAL(timeout()), this, SLOT(slotAnimTimer()));
+  connect(this, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotClicked()));
+  connect(m_animTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotAnimTimer()));
 }
 
 MultiTabBarButton::~MultiTabBarButton()
