@@ -197,7 +197,7 @@ public:
 class QueueView : public TQWidget
 {
 friend class QueueViewItem;
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Class constructor.
