@@ -64,7 +64,7 @@ class MultiTabBarTab;
  */
 class Sidebar : public TQWidget
 {
-Q_OBJECT
+TQ_OBJECT
 friend class Splitter;
 public:
     enum Position {
