@@ -55,7 +55,7 @@ class Balloon;
  */
 class SystemTray : public KSystemTray
 {
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Get the global system tray instance.
